@@ -6,22 +6,6 @@ Usage: get_first_person "person name"
 
 Search for the given name and print the best matching result.
 """
-# Parameters to initialize the IMDb class.
-IMDB_PARAMS = {
-    # The used access system. 'web' means that you're retrieving data
-    # from the IMDb web server.
-    'accessSystem': 'web'
-    #'accessSystem': 'mobile'
-    # XXX: if you've a local installation of the IMDb database,
-    # comment the above line and uncomment the following two.
-    #'accessSystem': 'local',
-    #'dbDirectory':  '/usr/local/imdb' # or, in a Windows environment:
-    #'dbDirectory':  'D:/imdb-20060107'
-
-    # XXX: parameters for a SQL installation.
-    #'accessSystem': 'sql',
-    #'uri': 'mysql://userName:yourPassword@localhost/dbName'
-}
 
 import sys
 
@@ -41,7 +25,7 @@ if len(sys.argv) != 2:
 name = sys.argv[1]
 
 
-i = imdb.IMDb(**IMDB_PARAMS)
+i = imdb.IMDb()
 
 in_encoding = sys.stdin.encoding or sys.getdefaultencoding()
 out_encoding = sys.stdout.encoding or sys.getdefaultencoding()
